<!-- 
    Security Knowledge Framework is an expert system application 
    that uses OWASP Application Security Verification Standard, code examples,
    helps developers in pre-development and post-development.  
    Copyright (C) 2015  Glenn ten Cate, Riccardo ten Cate

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
-->

{% include 'header.html' %}
 
<!-- **********************************************************************************************************************************************************
      MAIN CONTENT
      *********************************************************************************************************************************************************** -->
      <!--main content start-->
      <section id="main-content" class="page06 results">

		<section class="intro">
			<div class="inner">

				<div class="text">
				
				{% if entries.projectName != Null %}
					<h1>Function results</h1>
					<p>There were no Function results found. Create a project and use the Add functions form in order to create results.</p>
				{% else %}
					<h1>Function results</h1>
					<p>Summary of all function-results, you can download a DOCX file with the current security findings.</p>
				{% endif %}
				
				</div>
			</div>
		</section>		  

	  <section class="wrapper">

			{% if entries.projectName == Null %}
			{% else %}
			
			<a class="report" href="/results-function-docx/{{projectID|safe}}">
				<button class="btn btn-default"><i style="margin-right: 10px;" class="fa fa-file-word-o"></i> Download Report</button>
			</a>

			<div class="read">
				<a class="toggle" href="javascript:;">
					<i class="fa fa-arrows-h"></i>
				</a>
			</div>	  
				
			{% endif %}	  
	  
			<div class="row mt">
				<div class="col-lg-12">
						<div id="report">
						{% set counter = 0 -%}
						{% for entry in content %}
							<div class="modal-body"> 
								<div class="modal-header">{{entries[counter][8]}}</div>                 
								<div class="well"> {{entry}} </div>
							</div>
						{% set counter = counter + 1 %}
						{% endfor %}
						</div>
					</div>
				</div><!-- /col-md-12 -->
			</div><!-- /row -->
		</section><!--/wrapper -->
      </section><!-- /MAIN CONTENT -->
        
{% include 'footer.html' %} 
