/*
Template Name: DASHGUM FREE - Bootstrap 3.2 Admin Theme
Template Version: 1.0
Author: Carlos Alvarez
Website: http://blacktie.co
Custom design based upon this template: Erik de Kuijper
*/

/* Import fonts */
@import url(https://fonts.googleapis.com/css?family=Montserrat:700|Ruda:400,700,900);

/* BASIC THEME CONFIGURATION */
body {
    color: #797979;
	background: #f2f2f2;
    font-family: 'Ruda', sans-serif;
    padding: 0px !important;
    margin: 0px !important;
    font-size:13px;
}

ul li {
    list-style: none;
}
a { color: #515594; }
a:hover { color: #b8bddd; }
a, a:hover, a:focus {
    text-decoration: none;
    outline: none;
}

h1 { font-size: 2.2em; color: #515594; }

::selection {

    background: #4D6AA9;
    color: #fff;
}
::-moz-selection {
    background: #4D6AA9;
    color: #fff;
}

#container {
    width: 100%;
    height: 100%;
}

/* Bootstrap Modifications */
.modal-header {
	background: #515594;
}

.modal-title {
	color: white;
}

.btn-round {
	border-radius: 20px;
	-webkit-border-radius: 20px;
}

.accordion-heading .accordion-toggle {
	display: block;
	cursor: pointer;
	border-top: 1px solid #F5F5F5;
	padding: 5px 0px;
	line-height: 28.75px;
	text-transform: uppercase;
	color: #1a1a1a;
	background-color: #ffffff;
	outline: none !important;
	text-decoration: none;
}	



/*Theme Backgrounds*/

.bg-theme {
	background-color: #4D6AA9;
}

.bg-theme02 {
	background-color: #ac92ec;
}

.bg-theme03 {
  background-color: #48cfad;
}

.bg-theme04 {
  background-color: #ed5565;
}
/*Theme Buttons*/

.btn-theme {
  color: #fff;
  background-color: #4D6AA9;
  border-color: #48bcb4;
}
.btn-theme:hover,
.btn-theme:focus,
.btn-theme:active,
.btn-theme.active,
.open .dropdown-toggle.btn-theme {
  color: #fff;
  background-color: #48bcb4;
  border-color: #48bcb4;
}

.btn-theme03 {
  color: #fff;
  background-color: #515594;
  border-color: #44477c;
  transition: all 0.2s ease-in-out 0s;
}
.btn-theme03:hover,
.btn-theme03:focus,
.btn-theme03:active,
.btn-theme03.active,
.open .dropdown-toggle.btn-theme03 {
  color: #fff;
  background-color: #62669e;
  border-color: #565989;
}

.btn-clear-g {
	color: #48bcb4;
	background: transparent;
	border-color: #48bcb4;
}

.btn-clear-g:hover {
	color: white;
}

hr {
  margin-top: 20px;
  margin-bottom: 20px;
  border: 0;
  border-top: 1px solid #797979;
}



/*Helpers*/

.centered {
	text-align: center;
}

.goleft {
	text-align: left;
}

.goright {
	text-align: right;
}

.mt {
	margin-top: 25px;
}

.mb {
	margin-bottom: 25px;
}

.ml {
	margin-left: 5px;
	}

.no-padding {
	padding: 0 !important;
}

.no-margin {
	margin: 0 !important;
}

/*Exclusive Theme Colors Configuration*/

.label-theme {
	background-color: #4D6AA9;
}

.bg-theme {
	background-color: #4D6AA9;
}

ul.top-menu > li > .logout {
	font-size: 12px;
	padding: 22px 25px;
	background: #494949;
	color: #fff;
	-webkit-transition: all 0.3s ease;
    -moz-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    -ms-transition: all 0.3s ease;
    transition: all 0.3s ease;	
}
ul.top-menu > li > .logout i { 
	margin-right: 10px; 
	color: #b2b8f3; 
}


/*sidebar navigation*/

#sidebar {
    width: 210px;
    height: 100%;
    position: fixed;
    background: #494949;
	border-right: 1px solid #fff;
}

#sidebar h5 {
	color: #f2f2f2;
	font-weight: 700;
}

#sidebar ul li {
    position: relative;
}

#sidebar .sub-menu > .sub li  {
    padding-left: 32px;
}

#sidebar .sub-menu > .sub li:last-child {
    padding-bottom: 10px;
}
#sidebar .copy { float: left; width: 100%; padding: 15px 2.5%; margin-top: 15px; border-top: 1px solid #797979; }
#sidebar .copy a { 
	color: #797979; 
	text-decoration: none; 
	border-bottom: 1px dotted #797979; 
	-webkit-transition: all 0.3s ease;
    -moz-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    -ms-transition: all 0.3s ease;
    transition: all 0.3s ease;
}
#sidebar .copy a:hover { color: #fff; border-color: #fff; }

/*LEFT NAVIGATION ICON*/
.dcjq-icon {
    height:17px;
    width:17px;
    display:inline-block;
    background: url("../img/nav-expand.png") no-repeat top;
    border-radius:3px;
    -moz-border-radius:3px;
    -webkit-border-radius:3px;
    position:absolute;
    right:10px;
    top:15px;
}
.active .dcjq-icon {
    background: url("../img/nav-expand.png") no-repeat bottom;
    border-radius:3px;
    -moz-border-radius:3px;
    -webkit-border-radius:3px;
}
/*---*/

.nav-collapse.collapse {
    display: inline;
}

ul.sidebar-menu , ul.sidebar-menu li ul.sub{
    margin: -2px 0 0;
    padding: 0;
}

ul.sidebar-menu {
    margin-top: 75px;
}

#sidebar > ul > li > ul.sub {
    display: none;
}
#sidebar ul.sub .act { color: #fff; }

#sidebar > ul > li.active > ul.sub, #sidebar > ul > li > ul.sub > li > a {
    display: block;
}

ul.sidebar-menu li ul.sub li{
    background: #5c5c5c;
    margin-bottom: 0;
    margin-left: 0;
    margin-right: 0;
}

ul.sidebar-menu li ul.sub li:last-child{
    border-radius: 0 0 4px 4px;
    -webkit-border-radius: 0 0 4px 4px;
}

ul.sidebar-menu li ul.sub li a {
    font-size: 12px;
    padding: 6px 0;
    line-height: 35px;
    height: 35px;
    -webkit-transition: all 0.3s ease;
    -moz-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    -ms-transition: all 0.3s ease;
    transition: all 0.3s ease;
    color: #aeb2b7;
}

ul.sidebar-menu li ul.sub li a:hover {
	color: white;
	background: transparent;
}

ul.sidebar-menu li ul.sub li.active a {
    color: #4D6AA9;
    -webkit-transition: all 0.3s ease;
    -moz-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    -ms-transition: all 0.3s ease;
    transition: all 0.3s ease;
    display: block;
}

ul.sidebar-menu li{
    /*line-height: 20px !important;*/
    margin-bottom: 5px;
    margin-left:10px;
    margin-right:10px;
}

ul.sidebar-menu li.sub-menu{
    line-height: 15px;
}

ul.sidebar-menu li a span{
    display: inline-block;
}

ul.sidebar-menu li a{
    color: #aeb2b7;
    text-decoration: none;
    display: block;
    padding: 15px 0 15px 10px;
    font-size: 15px;
    outline: none;
    -webkit-transition: all 0.3s ease;
    -moz-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    -ms-transition: all 0.3s ease;
    transition: all 0.3s ease;
}

ul.sidebar-menu li a.active, ul.sidebar-menu li a:hover, ul.sidebar-menu li a:focus {
    background: #515594;
    color: #fff;
    display: block;

    -webkit-transition: all 0.3s ease;
    -moz-transition: all 0.3s ease;
    -o-transition: all 0.3s ease;
    -ms-transition: all 0.3s ease;
    transition: all 0.3s ease;
}


ul.sidebar-menu li a i {
    font-size: 15px;
    padding-right: 6px;
}

ul.sidebar-menu li a:hover i, ul.sidebar-menu li a:focus i {
    color: #fff;
}

ul.sidebar-menu li a.active i {
    color: #fff;
}
ul.sidebar-menu li a.act i { color: #b2b8f3; transition: all 0.2s ease-out; }
ul.sidebar-menu li a.act:hover i { color: #fff; }

.mail-info, .mail-info:hover {
    margin: -3px 6px 0 0;
    font-size: 11px;
}

/* MAIN CONTENT CONFIGURATION */
#main-content {
    margin-left: 210px;
	padding-bottom: 30px;
}

.header, .footer {
    min-height: 60px;
    padding: 0 15px;
}

.header {
    position: fixed;
    left: 0;
    right: 0;
    z-index: 1002;
	padding-right: 0;
}
.header .logo {
	font-family: Montserrat,"Helvetica Neue",Helvetica,Arial,sans-serif;
	font-size: 15px;
}
.header .logo img {
	margin-right: 6px;
}

.black-bg {
    background: #515594;
}
.intro {
    display: inline-block;
    margin-top: 60px;
    padding: 0 30px;
    width: 100%;
	background: #e8e8e8 url("../img/background.png");
	border-bottom: 1px solid #fff;
}
.intro .text {
	font-size: 20px;
	color: #7c81b5;
	text-shadow: 0 1px 1px #fff;
	float: left;
	width: 50%;
}
.intro .inner {
	float: left; padding: 30px 0; width: 100%;
}
.intro h1 {
	font-size: 1.3em;
}
.intro h1 span { display: inline-block; color: #b2b8f3; }

/* Data Panel */

.intro .data-panel { 
	float: left; width: 50%;
}
.intro .data-panel ul  {
	float: right;
	background: #f2f2f2;
	margin: 0; 
	padding: 10px;
	list-style: none;
	border: 1px solid #cccccc;
}
.intro .data-panel li {
	float: left; 
	width: 100%;
	padding: 5px 0;
	color: #494949;
}
.intro .data-panel .name {
	display: inline-block; 
	font-weight: bold;
}
.intro .data-panel .version { display: inline-block; padding: 5px;  } 
.intro .data-panel .update { display: inline-block; padding: 5px; } 
.intro .data-panel .update a { color: #519451; } 

.wrapper {
    display: block;
    margin-top: 60px;
    padding: 0 30px;
    width: 100%;
}

.dashboard .wrapper { margin-top: 30px; }

a.logo {
    font-size: 20px;
    color: #ffffff;
    float: left;
    margin-top: 15px;
	-webkit-transition: all 0.2s ease-in-out; 
	-moz-transition: all 0.2s ease-in-out; 
	-o-transition: all 0.2s ease-in-out; 
	transition: all 0.2s ease-in-out; 
}

a.logo b {
    font-weight: 900;
}

a.logo:hover, a.logo:focus {
    text-decoration: none;
    outline: none;
	color: #b8bdf1;
}

a.logo span {
    color: #4D6AA9;
}


/*notification*/
#top_menu .nav > li, ul.top-menu > li {
    float: left;
}

.notify-row {
    float: left;
    margin-top: 15px;
    margin-left: 92px;
}

.notify-row .notification span.label {
    display: inline-block;
    height: 18px;
    width: 20px;
    padding: 5px;
}

ul.top-menu > li > a {
    color: #666666;
    font-size: 16px;
    padding: 2px 6px;
}

ul.top-menu > li > a:hover, ul.top-menu > li > a:focus {
    text-decoration: none;
    color: #b6b6b6 !important;
}

.notify-row .badge {
    position: absolute;
    right: -10px;
    top: -10px;
    z-index: 100;
}

.dropdown-menu.extended {
    max-width: 300px !important;
    min-width: 160px !important;
    top: 42px;
    width: 235px !important;
    padding: 0;
    box-shadow: 0 2px 5px rgba(0, 0, 0, 0.176) !important;
    border: none !important;
    border-radius: 4px;
    -webkit-border-radius: 4px;
}

@media screen and (-webkit-min-device-pixel-ratio:0) {
    /* Safari and Chrome */
    .dropdown-menu.extended  {
        box-shadow: 0 2px 8px rgba(0, 0, 0, 0.176) !important;
    };
    }

.dropdown-menu.extended li p {
    background-color: #F1F2F7;
    color: #666666;
    margin: 0;
    padding: 10px;
    border-radius: 4px 4px 0px 0px;
    -webkit-border-radius: 4px 4px 0px 0px;
}

.dropdown-menu.extended li p.green {
    background-color: #4D6AA9;
    color: #fff;
}

.dropdown-menu.extended li p.yellow {
    background-color: #fcb322;
    color: #fff;
}

.dropdown-menu.extended li a {
    border-bottom: 1px solid #EBEBEB !important;
    font-size: 12px;
    list-style: none;
}

.dropdown-menu.extended li a {
    padding: 15px 10px !important;
    width: 100%;
    display: inline-block;
}

.dropdown-menu.extended li a:hover {
    background-color: #F7F8F9 !important;
    color: #2E2E2E;
}

.dropdown-menu.tasks-bar .task-info .desc {
    font-size: 13px;
    font-weight: normal;
}

.dropdown-menu.tasks-bar .task-info .percent {
    display: inline-block;
    float: right;
    font-size: 13px;
    font-weight: 600;
    padding-left: 10px;
    margin-top: -4px;
}

.dropdown-menu.extended .progress {
    margin-bottom: 0 !important;
    height: 10px;
}

.dropdown-menu.inbox li a .photo img {
    border-radius: 2px 2px 2px 2px;
    float: left;
    height: 40px;
    margin-right: 4px;
    width: 40px;
}

.dropdown-menu.inbox li a .subject {
    display: block;
}

.dropdown-menu.inbox li a .subject .from {
    font-size: 12px;
    font-weight: 600;
}

.dropdown-menu.inbox li a .subject .time {
    font-size: 11px;
    font-style: italic;
    font-weight: bold;
    position: absolute;
    right: 5px;
}

.dropdown-menu.inbox li a .message {
    display: block !important;
    font-size: 11px;
}

.top-nav  {
    margin-top: 7px;
}

.top-nav ul.top-menu > li .dropdown-menu.logout {
    width: 268px !important;

}

.top-nav li.dropdown .dropdown-menu {
    float: right;
    right: 0;
    left: auto;
}

.dropdown-menu.extended.logout > li {
    float: left;
    text-align: center;
    width: 33.3%;
}

.dropdown-menu.extended.logout > li:last-child {
    float: left;
    text-align: center;
    width: 100%;
    background: #a9d96c;
    border-radius: 0 0 3px 3px;
}

.dropdown-menu.extended.logout > li:last-child > a, .dropdown-menu.extended.logout > li:last-child > a:hover {
    color: #fff;
    border-bottom: none !important;
    text-transform: uppercase;
}

.dropdown-menu.extended.logout > li:last-child > a:hover > i{
    color: #fff;
}

.dropdown-menu.extended.logout > li > a {
    color: #a4abbb;
    border-bottom: none !important;
}

.full-width .dropdown-menu.extended.logout > li > a:hover {
    background: none !important;
    color: #50c8ea !important;
}

.dropdown-menu.extended.logout > li > a:hover {
    background: none !important;
}

.dropdown-menu.extended.logout > li > a:hover i {
    color: #50c8ea;
}

.dropdown-menu.extended.logout > li > a i {
    font-size: 17px;
}

.dropdown-menu.extended.logout > li > a > i {
    display: block;
}

.top-nav ul.top-menu > li > a {
    border: 1px solid #eeeeee;
    border-radius: 4px;
    -webkit-border-radius: 4px;
    padding: 6px;
    background: none;
    margin-right: 0;
}
.top-nav ul.top-menu > li {
    margin-left: 10px;
}

.top-nav ul.top-menu > li > a:hover, .top-nav ul.top-menu > li > a:focus {
    border:1px solid #F1F2F7;
    background: #F1F2F7;

}

.top-nav .dropdown-menu.extended.logout {
    top: 50px;
}

.top-nav .nav .caret {
    border-bottom-color: #A4AABA;
    border-top-color: #A4AABA;
}
.top-nav ul.top-menu > li > a:hover .caret {
    border-bottom-color: #000;
    border-top-color: #000;
}

.log-arrow-up {
    background: url("../img/arrow-up.png") no-repeat;
    width: 20px;
    height: 11px;
    position: absolute;
    right: 20px;
    top: -10px;
}

/*----*/

.notify-arrow {
    border-style: solid;
    border-width: 0 9px 9px;
    height: 0;
    margin-top: 0;
    opacity: 0;
    position: absolute;
    left: 7px;
    top: -18px;
    transition: all 0.25s ease 0s;
    width: 0;
    z-index: 10;
    margin-top: 10px;
    opacity: 1;
}

.notify-arrow-yellow {
    border-color: transparent transparent #FCB322;
    border-bottom-color: #FCB322 !important;
    border-top-color: #FCB322 !important;
}
.notify-arrow-green {
    border-color: transparent transparent #4D6AA9;
    border-bottom-color: #4D6AA9 !important;
    border-top-color: #4D6AA9 !important;
}



/*--sidebar toggle---*/

.sidebar-toggle-box {
    float: left;
    padding-right: 15px;
    margin-top: 20px;
}

.sidebar-toggle-box .fa-bars {
    cursor: pointer;
    display: inline-block;
    font-size: 20px;
}


.sidebar-closed > #sidebar > ul {
    display: none;
}

.sidebar-closed #main-content {
    margin-left: 0px;
}

.sidebar-closed #sidebar {
    margin-left: -180px;
}

/* Dashboard Panel */

.content-panel.selection { width: 100%; margin: 0 auto; max-width: 1000px; }
.content-panel.selection ul { margin: 0; padding: 0; list-style: none; }
.content-panel.selection li { margin: 0; padding: 0; float: left; position: relative; text-align: center; }
.content-panel.selection.four li { width: 25%; }
.content-panel.selection.three li { width: 33%; }
.content-panel.selection .row { float: left; width: 100%; margin: 0; }
.content-panel.selection a { text-align: center; width: 50%; margin: 0 25%; float: left; }
.content-panel.selection .icon { display: block; margin: 0 auto; width: 100px; height: 100px; position: relative; border-radius: 100px; background: #494949; transition: all 0.2s ease; box-shadow: 0px 1px 1px #fff; bottom: 0; }
.content-panel.selection .icon i { margin-top: 25px; color: #fff; }
.content-panel.selection a:hover .icon { background: #515594; bottom: 5px; }
.content-panel.selection .name { display: block; color: #494949; margin-top: 15px; }

.content-panel.selection .back { width: 50px; height: 50px; font-size: 2em; position: absolute; left: -10px; top: 25%; color: #bfbfbf; text-shadow: 0px 1px 1px #fff; margin: 0; transition: all 0.2s ease; }
.content-panel.selection .back:before { content: "\f053"; font-family: "fontawesome"; }
.content-panel.selection .back:hover { color: #494949; }
.content-panel.selection .middle:before { width: 50px; height: 50px; content: "\f054"; font-family: "fontawesome"; font-size: 2em; position: absolute; left: -10px; top: 25%; color: #bfbfbf; text-shadow: 0px 1px 1px #fff; }
.content-panel.selection .middle:after { width: 50px; height: 50px; content: "\f054"; font-family: "fontawesome"; font-size: 2em; position: absolute; right: -10px; top: 25%; color: #bfbfbf; text-shadow: 0px 1px 1px #fff; text-align: right; }

.content-panel.selection .dev { 
    background: #515594;
    border-radius: 10px;
    bottom: -26px;
    color: #fff;
    font-size: 0.8em;
    padding: 3px 10px;
    text-align: center;
    display: inline-block;
	margin-top: 10px;
 }

/* Search */

.search { float: left; margin-bottom: 30px; background: #494949; border-bottom: 1px solid #fff; }
.search input[type="search"] { border: none; color: #fff; padding: 15px 20px; background: transparent; }
.search button { border: none; background: transparent; color: #fff; padding: 0 20px; }
.search i { margin: 0 20px; }

/* Read */

.read { float: left; margin-left: 10px; }
.read a { background: #494949; border-bottom: 1px solid #fff; color: #fff; width: 50px; height: 50px; padding: 15px; font-size: 13px; display: inline-block; margin-left: 10px; text-align: center; transition: all 0.2s ease; }
.read a:hover { background: #515594; }
.read a.act { background: #515594; }

.wrapper #accordion { transition: all 0.2s ease; width: 100%; margin: 0 auto; }
.wrapper.narrow #accordion { display: block; width: 700px; }
.wrapper #report { transition: all 0.2s ease; width: 100%; margin: 0 auto; }
.wrapper.narrow #report { display: block; width: 700px; }

/* Product Panel */
.product-panel {
	background: #dadad2;
	text-align: center;
	padding-top: 50px;
	height: 100%;
}

/* Product Panel 2*/
.product-panel-2 {
	background: #dadad2;
	text-align: center;
}
.product-panel-2 .badge {
	position: absolute;
	top: 20px;
	left: 35px;
}
.badge-hot {
	background: #ed5565;
	width: 70px;
	height: 70px;
	line-height: 70px;
	font-size: 18px;
	color: #fff;
	text-align: center;
	border-radius: 100%;
}

/* Soptify Panel */
#spotify {
	background: url(../img/lorde.jpg) no-repeat center top;
	margin-top: -15px;
	background-attachment: relative;
	background-position: center center;
	min-height: 220px;
	width: 100%;
    -webkit-background-size: 100%;
    -moz-background-size: 100%;
    -o-background-size: 100%;
    background-size: 100%;
    -webkit-background-size: cover;
    -moz-background-size: cover;
    -o-background-size: cover;
    background-size: cover;
}
#spotify .btn-clear-g {
	top: 15%;
	right: 10px;
	position: absolute;
	margin-top: 5px;
}
#spotify .sp-title {
	bottom: 15%;
	left: 25px;
	position: absolute;
	color: #efefef;
}
#spotify .sp-title h3 {
	font-weight: 900;
}
#spotify .play{
	bottom: 18%;
	right: 25px;
	position: absolute;
	color: #efefef;
	font-size: 20px
}
.followers {
	margin-left: 5px;
	margin-top: 5px;
}

/* BLOG PANEL */
#blog-bg {
	background: url(../img/blog-bg.jpg) no-repeat center top;
	margin-top: -15px;
	background-attachment: relative;
	background-position: center center;
	min-height: 150px;
	width: 100%;
    -webkit-background-size: 100%;
    -moz-background-size: 100%;
    -o-background-size: 100%;
    background-size: 100%;
    -webkit-background-size: cover;
    -moz-background-size: cover;
    -o-background-size: cover;
    background-size: cover;
}
#blog-bg .badge {
	position: absolute;
	top: 20px;
	left: 35px;
}
.badge-popular {
	background: #3498db;
	width: 70px;
	height: 70px;
	line-height: 70px;
	font-size: 13px;
	color: #fff;
	text-align: center;
	border-radius: 100%;
}
.blog-title {
	background: rgba(0,0,0,0.5);
	bottom: 100px;
	padding: 6px;
	color: white;
	font-weight: 700;
	position: absolute;
	display: block;
	width: 120px;
}
.blog-text {
	margin-left: 8px;
	margin-right: 8px;
	margin-top: 15px;
	font-size: 12px;
}

/* Calendar Configuration */
#calendar {
	color: white;
	padding: 0px !important;
}
.calendar-month-header {
	background: #43b1a9;
}

/* TODO PANEL */
.steps{
  display: block;
}
.steps input[type=checkbox] {
  display: none;
}
.steps input[type=submit]{
  background: #f1783c;
  border: none;
  padding: 0px;
  margin: 0 auto;
  width: 100%;
  height: 55px;
  color: white;
  text-transform: uppercase;
  font-weight: 900;
  font-size: 11px;
  letter-spacing: 1px;
  cursor: pointer;
  transition: background 0.5s ease
}
.steps input[type=submit]:hover{
  background: #8fde9c;
}
.steps label{
  background: #393D40;
  height: 65px;
  line-height: 65px;
  width: 100%;
  display: block;
  border-bottom: 1px solid #44494e;
  color: #889199;
  text-transform: uppercase;
  font-weight: 900;
  font-size: 11px;
  letter-spacing: 1px;
  text-indent: 52px;
  cursor: pointer;
  transition: all 0.7s ease;
  margin: 0px;
}
.steps label:before{
  content:"";
  width: 12px;
  height: 12px;
  display: block;
  position: absolute;
  margin: 26px 0px 0px 18px;
  border-radius: 100%;
  transition: border 0.7s ease
}
.steps label:hover{
  background: #2B2E30;
  color: #46b7e5
}
.steps label:hover:before{
  border: 1px solid #46b7e5;
}
#op1:checked ~ label[for=op1]:before,
#op2:checked ~ label[for=op2]:before,
#op3:checked ~ label[for=op3]:before{
  border: 2px solid #96c93c;
  background: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAgAAAAHCAYAAAA1WQxeAAAAGXRFWHRTb2Z0d2FyZQBBZG9iZSBJbWFnZVJlYWR5ccllPAAAAGFJREFUeNpinHLMhgEHKADia0xQThIQs6JJ9gPxZhYQAcS6QHwDiI8hSYJAC0gBPxDLAvFcIJ6JJJkDxFNBVtgBcQ8Qa6BLghgwN4A4a9ElQYAFSj8C4mwg3o8sCQIAAQYA78QTYqnPZuEAAAAASUVORK5CYII=') no-repeat center center;
}

/* PROFILE PANELS */
/* Profile 01*/
#profile-01 {
	background: url(../img/profile-01.jpg) no-repeat center top;
	margin-top: -15px;
	background-attachment: relative;
	background-position: center center;
	min-height: 150px;
	width: 100%;
    -webkit-background-size: 100%;
    -moz-background-size: 100%;
    -o-background-size: 100%;
    background-size: 100%;
    -webkit-background-size: cover;
    -moz-background-size: cover;
    -o-background-size: cover;
    background-size: cover;
}
#profile-01 h3 {
	color: white;
	padding-top: 50px;
	margin: 0px;
	text-align: center;
}
#profile-01 h6 {
	color: white;
	text-align: center;
	margin-bottom: 0px;
	font-weight: 900;
}
.profile-01 {
	background: #4D6AA9;
	height: 50px;
}
.profile-01:hover {
	background: #2f2f2f;
  -webkit-transition: background-color 0.6s;
  -moz-transition: background-color 0.6s;
  -o-transition: background-color 0.6s;
  transition: background-color 0.6s;
  cursor: pointer;
}
.profile-01 p {
	color: white;
	padding-top: 15px;
	font-weight: 400;
	font-size: 15px;
}

/* Profile 02*/
#profile-02 {
	background: url(../img/profile-02.jpg) no-repeat center top;
	margin-top: -15px;
	background-attachment: relative;
	background-position: center center;
	min-height: 200px;
	width: 100%;
    -webkit-background-size: 100%;
    -moz-background-size: 100%;
    -o-background-size: 100%;
    background-size: 100%;
    -webkit-background-size: cover;
    -moz-background-size: cover;
    -o-background-size: cover;
    background-size: cover;
}
#profile-02 .user {
	padding-top: 40px;
	text-align: center;
}
#profile-02 h4 {
	color: white;
	margin:0px;
	padding-top: 8px;
}
.pr2-social a {
	color: #cdcdcd;
}
.pr2-social a:hover {
	color: #4D6AA9;
}
.pr2-social i {
	margin-top: 15px;
	margin-right: 12px;
	font-size: 20px;
}


/*spark line*/
.chart {
    display: inline-block;
    text-align: center;
    width: 100%;
}
.chart .heading {
    text-align: left;
}
.chart .heading span {
    display: block;
}
.panel.green-chart .chart-tittle {
    font-size: 16px;
    padding: 15px;
    display: inline-block;
    font-weight:normal;
    background: #99c262;
    width: 100%;
    -webkit-border-radius: 0px 0px 4px 4px;
    border-radius: 0px 0px 4px 4px;
}
#barchart {
    margin-bottom: -15px;
    display: inline-block;
}
.panel.green-chart .chart-tittle .value {
    float: right;
    color: #c0f080;
}
.panel.green-chart {
    background: #a9d96c;
    color: #fff;
}
.panel.terques-chart {
    background: transparent;
    color: #797979;
}
.panel.terques-chart .chart-tittle .value {
    float: right;
    color: #fff;
}
.panel.terques-chart .chart-tittle .value a {
    color: #2f2f2f;
    font-size: 12px;
}
.panel.terques-chart .chart-tittle .value a:hover, .panel.terques-chart .chart-tittle .value a.active {
    color: #4D6AA9;
    font-size: 12px;
}
.panel.terques-chart .chart-tittle {
    font-size: 16px;
    padding: 15px;
    display: inline-block;
    font-weight:normal;
    background: #39b7ac;
    width: 100%;
    -webkit-border-radius: 0px 0px 4px 4px;
    border-radius: 0px 0px 4px 4px;
}
.inline-block {
    display: inline-block;
}

/* showcase background */
.showback {
	background: #ffffff;
	padding: 15px;
	margin-bottom: 15px;
	box-shadow: 0px 3px 2px #aab2bd;
}



/* Calendar Events - Calendar.html*/
.external-event {
	cursor: move;
	display: inline-block !important;
	margin-bottom: 7px !important;
	margin-right: 7px !important;
	padding: 10px;
}

.drop-after {
	padding-top: 15px;
	margin-top: 15px;
	border-top: 1px solid #ccc;
}

.fc-state-default, .fc-state-default .fc-button-inner {
	background: #f2f2f2;
}

.fc-state-active .fc-button-inner {
	background: #FFFFFF;
}

/* Gallery Configuration */
.photo-wrapper {
  display: block;
  position: relative;
  overflow: hidden;
  background-color: #4D6AA9;
  -webkit-transition: background-color 0.4s;
  -moz-transition: background-color 0.4s;
  -o-transition: background-color 0.4s;
  transition: background-color 0.4s;
}
.project .overlay {
  position: absolute;
  text-align: center;
  color: #fff;
  opacity: 0;
  filter: alpha(opacity=0);
  -webkit-transition: opacity 0.4s;
  -moz-transition: opacity 0.4s;
  -o-transition: opacity 0.4s;
  transition: opacity 0.4s;
  
}

.project:hover .photo-wrapper {
  background-color: #4D6AA9;
	background-image:url(../img/zoom.png);
	background-repeat:no-repeat;
	background-position:center;
	top: 0;
	bottom: 0;
	left: 0;
	right: 0;
	position: relative;
}
.project:hover .photo {
  opacity: 10;
  filter: alpha(opacity=4000);
  opacity: 0.1;
  filter: alpha(opacity=40);
}
.project:hover .overlay {
  opacity: 100;
  filter: alpha(opacity=10000);
  opacity: 1;
  filter: alpha(opacity=100);
}



/* EZ Checklist */
.ez-checkbox {
	margin-right: 5px;
}

.ez-checkbox, .ez-radio {
	height: 20px;
	width: 20px;
}

.brand-highlight {
background: #fffbcc !important;
}


/* FORMS CONFIGURATION */
.form-panel {
	background: #ffffff;
	margin: 10px;
	padding: 10px;
	box-shadow: 0px 3px 2px #aab2bd;
	text-align: left;
}

label {
	font-weight: 400;
}

.form-horizontal.style-form .form-group {
	border-bottom: 1px solid #eff2f7;
	padding-bottom: 15px;
	margin-bottom: 15px;
}

.round-form {
	border-radius: 500px;
	-webkit-border-radius: 500px;
}

#focusedInput {
	border: 1px solid #ed5565;
	box-shadow: none;
}

.add-on {
	float: right;
	margin-top: -37px;
	padding: 3px;
	text-align: center;
}

.add-on .btn {
	height: 34px;
}

/* TOGGLE CONFIGURATION */
.has-switch {
    border-radius: 30px;
    -webkit-border-radius: 30px;
    display: inline-block;
    cursor: pointer;
    line-height: 1.231;
    overflow: hidden;
    position: relative;
    text-align: left;
    width: 80px;
    -webkit-mask: url('../img/mask.png') 0 0 no-repeat;
    mask: url('../img/mask.png') 0 0 no-repeat;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    -o-user-select: none;
    user-select: none;
}
.has-switch.deactivate {
    opacity: 0.5;
    filter: alpha(opacity=50);
    cursor: default !important;
}
.has-switch.deactivate label,
.has-switch.deactivate span {
    cursor: default !important;
}
.has-switch > div {
    width: 162%;
    position: relative;
    top: 0;
}
.has-switch > div.switch-animate {
    -webkit-transition: left 0.25s ease-out;
    -moz-transition: left 0.25s ease-out;
    -o-transition: left 0.25s ease-out;
    transition: left 0.25s ease-out;
    -webkit-backface-visibility: hidden;
}
.has-switch > div.switch-off {
    left: -63%;
}
.has-switch > div.switch-off label {
    background-color: #7f8c9a;
    border-color: #bdc3c7;
    -webkit-box-shadow: -1px 0 0 rgba(255, 255, 255, 0.5);
    -moz-box-shadow: -1px 0 0 rgba(255, 255, 255, 0.5);
    box-shadow: -1px 0 0 rgba(255, 255, 255, 0.5);
}
.has-switch > div.switch-on {
    left: 0%;
}
.has-switch > div.switch-on label {
    background-color: #41cac0;
}
.has-switch input[type=checkbox] {
    display: none;
}
.has-switch span {
    cursor: pointer;
    font-size: 14.994px;
    font-weight: 700;
    float: left;
    height: 29px;
    line-height: 19px;
    margin: 0;
    padding-bottom: 6px;
    padding-top: 5px;
    position: relative;
    text-align: center;
    width: 50%;
    z-index: 1;
    -webkit-box-sizing: border-box;
    -moz-box-sizing: border-box;
    box-sizing: border-box;
    -webkit-transition: 0.25s ease-out;
    -moz-transition: 0.25s ease-out;
    -o-transition: 0.25s ease-out;
    transition: 0.25s ease-out;
    -webkit-backface-visibility: hidden;
}
.has-switch span.switch-left {
    border-radius: 30px 0 0 30px;
    background-color: #2A3542;
    color: #41cac0;
    border-left: 1px solid transparent;
}
.has-switch span.switch-right {
    border-radius: 0 30px 30px 0;
    background-color: #bdc3c7;
    color: #ffffff;
    text-indent: 7px;
}
.has-switch span.switch-right [class*="fui-"] {
    text-indent: 0;
}
.has-switch label {
    border: 4px solid #2A3542;
    border-radius: 50%;
    -webkit-border-radius: 50%;
    float: left;
    height: 29px;
    margin: 0 -21px 0 -14px;
    padding: 0;
    position: relative;
    vertical-align: middle;
    width: 29px;
    z-index: 100;
    -webkit-transition: 0.25s ease-out;
    -moz-transition: 0.25s ease-out;
    -o-transition: 0.25s ease-out;
    transition: 0.25s ease-out;
    -webkit-backface-visibility: hidden;
}
.switch-square {
    border-radius: 6px;
    -webkit-border-radius: 6px;
    -webkit-mask: url('../img/mask.png') 0 0 no-repeat;
    mask: url('../img/mask.png') 0 0 no-repeat;
}
.switch-square > div.switch-off label {
    border-color: #7f8c9a;
    border-radius: 6px 0 0 6px;
}
.switch-square span.switch-left {
    border-radius: 6px 0 0 6px;
}
.switch-square span.switch-left [class*="fui-"] {
    text-indent: -10px;
}
.switch-square span.switch-right {
    border-radius: 0 6px 6px 0;
}
.switch-square span.switch-right [class*="fui-"] {
    text-indent: 5px;
}
.switch-square label {
    border-radius: 0 6px 6px 0;
    border-color: #41cac0;
}



/*LOGIN CONFIGURATION PAGE*/
.form-login {
	max-width: 330px;
	margin: 100px auto 0;
	background: #fff;
	border-radius: 5px;
	-webkit-border-radius: 5px;
}

.form-login h2.form-login-heading {
	margin: 0;
	padding: 25px 20px;
	text-align: center;
	background: #4D6AA9;
	border-radius: 5px 5px 0 0;
	-webkit-border-radius: 5px 5px 0 0;
	color: #fff;
	font-size: 20px;
	text-transform: uppercase;
	font-weight: 300;
}
.login-wrap {
	padding: 20px;
}
.login-wrap .registration {
	text-align: center;
}
.login-social-link {
	display: block;
	margin-top: 20px;
	margin-bottom: 15px;
}


/*LOCK SCREEN CONF*/
#showtime {
	width: 100%;
	color: #fff;
	font-size: 90px;
	margin-bottom: 30px;
	margin-top: 250px;
	display: inline-block;
	text-align: center;
	font-weight: 400;
}

.lock-screen {
	text-align: center;
}

.lock-screen a {
	color: white;
}

.lock-screen a:hover {
	color: #b8bdf1;
}

.lock-screen i {
	font-size: 60px;
}

.lock-screen .modal-content {
	position: relative;
	background-color: #f2f2f2;
	background-clip: padding-box;
	border: 1px solid #999;
	border: 1px solid rgba(0, 0, 0, .2);
	border-radius: 5px;
}

/*flot chart*/
.flot-chart .chart, .flot-chart .pie, .flot-chart .bars {
    height: 300px;
}

/*footer*/
.site-footer {
	border-top: 1px solid #ccc;
    color: #bfbfbf;
    padding: 10px 0;
	margin-left: 210px;
	text-shadow: 0px 1px 1px #fff;
	clear: both;
}


.go-top {
    margin-right: 1%;
    float: right;
    background: rgba(255,255,255,.5);
    width: 20px;
    height: 20px;
    border-radius: 50%;
    -webkit-border-radius: 50%;
}

.go-top i {
    color: #2A3542;
}

.site-min-height {
    min-height: 900px;
}

/* Custom */

#login { background: #494949; }
#login .col-wrapper { width: 450px; margin: 0 auto; padding: 10% 0 0; }
#login .modal-dialog { width: 450px; }

/* Panels */

.panel { box-shadow: none; }
.panel-default > .panel-heading { background: transparent; border: none; border-top-left-radius: 0px; border-top-right-radius: 0px; padding: 0; }
.panel-heading a { display: block; width: 100%; background: #e7e7e7; border: none; color: #333; border-top-left-radius: 3px; border-top-right-radius: 3px; padding: 10px 15px; transition: all 0.2s ease-out; position: relative; }
.panel-heading a.collapsed:hover { background: #e7e7e7; }
.panel-heading a.collapsed { background: #fff; }
.panel-heading a.collapsed:after { content:"\f054"; color: #dddddd; }
.panel-heading a.collapsed:hover:after { color: #494949; }
.panel-heading a:after { display: block; width: 16px; height: 16px; font-family: "fontawesome"; position: absolute; right: 10px; top: 10px; color: #494949; content:"\f078"; transition: all 0.2s ease-out; }
.panel-body { background: #fff; }
.panel-body h2 { font-size: 2em; color: #515594; margin-top: 0; }
.panel-body-inner { float: left; width: 100%; padding: 10px 0; }
.panel-body pre { background-color: #515594; }
.panel.noMatch { display: none; }

/* Forms */

.btn-default { background: #515594; color: #fff; border: 1px solid #515594; transition: all 0.2s ease-out; border-radius: 0px;  }
.btn-default:hover { background: #7c81b5; color: #fff; border: 1px solid #7c81b5; }
.new-project .wrap { float: left; width: 100%; }
.new-project .wrap.desc { color: #bfbfbf; text-shadow: 0px 1px 1px #fff; }
.new-project span.desc { color: #bfbfbf; text-shadow: 0px 1px 1px #fff; display: inline-block; margin-left: 15px; }

/* New Project */

.table-striped > tbody > tr:nth-child(2n+2) > td, 
.table-striped > tbody > tr:nth-child(2n+2) > th { background: #eaeaea; }
.table-striped > tbody > tr:hover:nth-child(2n+2) > td, 
.table-striped > tbody > tr:hover:nth-child(2n+2) > th { background: #eeeeee; }

.table-striped > tbody > tr.checked > td { background: #f6fff7; color: #62a06a; border-top: 1px solid #d5e5d7; }
.table-striped > tbody > tr.checked:nth-child(2n+2) > td { background: #e5efe6; color: #62a06a; }

/*.table-striped > tbody > tr.false > td { background: #efe5e5; color: #a66c6c; border-top: 1px solid #e5d5d5; }
.table-striped > tbody > tr.false:nth-child(2n+2) > td { background: #fbf9f9; color: #a66c6c; }*/

.table-striped > tbody > tr.exclude > td { background: #f9f9f9; color: #e3dbdb; border-top: 1px solid #f5f5f5; }
.table-striped > tbody > tr.exclude:nth-child(2n+2) > td { background: #fdfdfd; color: #d9dada; }

.table-striped > tbody > tr > td:first-child a { padding: 4px 9px; transition: all 0.2s ease-out; border: 1px solid #f9f9f9; } 
.table-striped > tbody > tr:nth-child(2n+2) > td:first-child a { border: 1px solid #eaeaea; } 

.table-striped > tbody > tr:hover > td:first-child a { background: #eaeaea; padding: 4px 9px; border: 1px solid #dddddd; } 
.table-striped > tbody > tr:hover:nth-child(2n+2) > td:first-child a { background: #f5f5f5; padding: 4px 9px; border: 1px solid #dddddd; } 

.table-striped > tbody > tr:hover > td:first-child a:hover { background: #515594; color: #fff; } 
.table-striped > tbody > tr > th { background: #494949 !important; font-size: 20px; color: #fff; font-weight: normal; } 
.table-striped > tbody > tr > th p { margin: 0; } 

.table > thead > tr > th { text-shadow: 0px 1px 1px #fff; color: #494949; border-bottom: 1px solid #fff; }
.table { border-bottom: 1px solid #fff; }
.table th i { color: #515594; margin-right: 10px; }
.table .label-info { background: #494949; padding: 0.3em 0.6em; }

/* Alert */

.alert-info { border-color: #d6d6d6; border-radius: 0px; background: #e8e8e8; color: #727272; text-shadow: 0px 1px 1px #fff; box-shadow: 0px 1px 1px #fff; }
.alert-info ul { display: inline-block; margin: 0; padding: 10px 0; list-style: none; }
.alert-info li { display: inline-block; margin: 2px; list-style: none; padding: 2px 3px; background: #f2f2f2; border: 1px solid #d6d6d6; float: left; }
.btn-danger { border-radius: 0; }

/* Project-Functions */

.project-functions .modal-dialog .tbl_container { width: 100%; height: auto; }
.project-functions .modal-dialog .row { margin: 0; float: left; width: 100%; padding: 2px 0; }
.project-functions .modal-dialog .row .left { float: left; width: 47.5%; }
.project-functions .modal-dialog .row .right { float: right; width: 47.5%; color: #bfbfbf; text-shadow: 0 1px 1px #fff; padding: 7px 0; }
.project-functions .modal-dialog .row .wide { border-top: 1px solid #d6d6d6; padding: 10px 0; float: left; width: 100%; margin-top: 15px; padding-top: 15px; }
.project-functions .nav,
.project-functions .mt,
.project-functions .modal-dialog .modal-content,
.project-functions .modal-dialog .modal-body,
.project-functions .modal-dialog .modal-footer { float: left; width: 100%; }
.project-functions .modal-dialog #checkboxes { float: left; width: 100%; padding: 15px 0; }
.project-functions .modal-dialog #checkboxes .item { float: left; width: 48%; padding: 15px; background: #e8e8e8; margin: 5px 1%; border-top: 1px solid #d6d6d6; border-bottom: 1px solid #d6d6d6; }
.project-functions .nav .btn { float: left; }
.modal-info { padding: 15px; float: left; width: 100%; }
.project-checklist .modal-dialog .back,
.nav .back { display: block; float: left; background: #494949; color: #fff; padding: 6px 12px; border: 1px solid #494949; margin-left: 10px; font-size: 14px; transition: all 0.2s ease-out;  }
.project-checklist .modal-dialog .back i,
.nav .back i { margin-left: 10px; transition: all 0.2s ease-out; }
.project-checklist .modal-dialog .back:hover,
.nav .back:hover { background: #5c5c5c; }
.project-checklist .modal-dialog .back:hover i,
.nav .back:hover i { color: #b2b8f3; }

/* Project Checklist */

.project-checklist .modal-dialog { width: 100%; max-width: 800px; font-size: 0.9em; }
.project-checklist .modal-dialog .back { float: none; display: inline-block; }
.project-checklist .modal-dialog .form-control { height: 26px; padding: 2px 12px; font-size: inherit; }
.project-checklist .more { width: 30px; text-align: center; font-size: 19px; }
.project-checklist .select { width: 85px; }
.project-checklist .tooltip.left { max-width: 500px; }

ul.level { margin: 0; padding: 0; list-style: none; }
ul.level li { display: block; float: left; margin: 0 2px; width: 8px; height: 8px; border-radius: 8px; }
ul.level li.yellow { background: #ffcc33; }
ul.level li.green { background: #66cc00; }
ul.level li.blue { background: #6699cc; }

.results .level { float: right; margin: 19px 20px; }

.project-checklist .legend { float: left; padding: 20px; border: 1px solid #d6d6d6; background: #e8e8e8; box-shadow: 0 1px 1px #fff; text-shadow: 0 1px 1px #fff; }
.project-checklist .legend h5 { color: #494949; }
.project-checklist .legend i {clear: both; float: left; font-size: 0.9em; padding: 0 0 10px; }
.project-checklist ul.level-legend { margin: 0; padding: 0; list-style: none; display: block; clear: both; float: left; }
.project-checklist ul.level-legend li { display: block; float: left; position: relative; }
.project-checklist ul.level-legend li.pip  { margin-top: 4px; }
.project-checklist ul.level-legend li.pip:after  { content: ""; display: block; float: left; margin-left: 2px; margin-right: 2px; width: 8px; height: 8px; border-radius: 8px; }
.project-checklist ul.level-legend li.yellow:after { background: #ffcc33; }
.project-checklist ul.level-legend li.green:after { background: #66cc00; }
.project-checklist ul.level-legend li.blue:after { background: #6699cc; }
.project-checklist ul.level-legend li.name { margin-left: 10px; }

/* Checklist Result */

.results .modal-body { padding-left: 0; padding-right: 0; }
.results .modal-header { background: #494949; padding: 0 15px; }
.results .modal-header { font-size: 20px; color: #fff; padding: 8px 15px; margin: 0; }
.results .modal-header p { padding: 0; margin: 0; }
.results .well { background: #fff; border-radius: 0; border-top: none; margin: 0; }
.results .well h2 { font-size: 18px; color: #515594; padding: 8px 0; margin: 0; }
.results .report { float: left; display: block; }
.results .report .btn { line-height: 15px; padding: 16px; }

/* Dropdown */

.dropdown-menu .label { background: #515594; border-radius: 10px; color: #fff; font-size: 0.8em; padding: 3px 10px; text-align: center; display: inline-block; margin-left: 10px; }

/* Select */

.project-functions #selectable li { cursor: pointer; transition: all 0.2s ease-in-out 0s; }
.project-functions #selectable li:hover { border-color: #515594; }
.project-functions .ui-selected { background: #515594; border-color: #515594; color: #fff; text-shadow: none; }
.project-functions .functions { float: left; width: 100%; }
.project-functions .functions .tbl_container { float: left; width: 100%; max-width: 600px; margin-top: 30px; }
.project-functions .functions .row { float: left; margin: 0; padding: 2px 0; width: 100%; }
.project-functions .functions .row .left { float: left; width: 47.5%; }
.project-functions .functions .row .right { color: #a1a1a1; float: right; padding: 7px 0; text-shadow: 0 1px 1px #fff; width: 47.5%; }
.project-functions .functions form { float: left; width: 100%; }