<!-- 
    Security Knowledge Framework is an expert system application 
    that uses OWASP Application Security Verification Standard, code examples,
    helps developers in pre-development and post-development.  
    Copyright (C) 2015  Glenn ten Cate, Riccardo ten Cate

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
-->

{% include 'header.html' %}

<!-- **********************************************************************************************************************************************************
      MAIN CONTENT
      *********************************************************************************************************************************************************** -->
      <!--main content start-->
      <section id="main-content" class="page03 getting-started">

          <section class="intro">
			<div class="inner">

				<div class="text">

				<h1>Alright, let's get started</h1>
				<p>Based on the processing functions you provide the framework will provide you with a fitting security checklist for your project.</p>

				</div>

			</div>
		  </section>
   
          <section class="wrapper">

		  		<div class="row mt">
			  		<div class="col-lg-12">
						<div class="content-panel selection three">
							<div class="row">
								<ul>
									<li>
										<a class="back" href="/project-list"></a>
										<a href="/project-functions/{{project_id|safe}}">
											<span class="icon"><i class="fa fa-file-code-o fa-4x"></i></span>
											<span class="name">Add processing functions</span>
										</a>
										<span class="dev">pre-development</span>
									</li>
									<li class="middle">
										<a href="/project-checklists/{{project_id|safe}}">
											<span class="icon"><i class="fa fa-file-text-o fa-4x"></i></span>
											<span class="name">Run checklist</span>
										</a>
										<span class="dev">post-development</span>
									</li>
									<li>
										<a href="/knowledge-base">
											<span class="icon"><i class="fa fa-book fa-4x"></i></span>
											<span class="name">Security knowledge base</span>
										</a>
									</li>
								</ul>
							</div>
						</div>
					</div>
               </div>			  

		</section><!--/wrapper -->
      </section><!-- /MAIN CONTENT -->
         

{% include 'footer.html' %}
