<!-- 
    Security Knowledge Framework is an expert system application 
    that uses OWASP Application Security Verification Standard, code examples,
    helps developers in pre-development and post-development.  
    Copyright (C) 2015  Glenn ten Cate, Riccardo ten Cate

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
-->
      <!--footer start-->
      <footer class="site-footer">
          <div  class="text-center">
             
			&copy; {{ year|safe }} - Security Knowledge Framework

			<a href="#" onclick="$('html, body').animate({ scrollTop: 0 }, 'fast');" class="go-top">
				<i class="fa fa-angle-up"></i>
			</a>
			  
          </div>
      </footer>
      <!--footer end-->
  </section>

    <!-- js placed at the end of the document so the pages load faster -->

    <script src="{{ url_for('static', filename='js/bootstrap.min.js') }}"></script>
	<script class="include" src="{{ url_for('static', filename='js/jquery.dcjqaccordion.2.7.js') }}"></script>
    <script src="{{ url_for('static', filename='js/prefixfree.min.js') }}"></script>
    <script src="{{ url_for('static', filename='js/jquery.scrollTo.min.js') }}"></script>
    <script src="{{ url_for('static', filename='js/jquery.nicescroll.js') }}"></script>
    <script src="{{ url_for('static', filename='js/animsition/jquery.animsition.min.js') }}"></script>
    <script src="{{ url_for('static', filename='js/jquery-ui.min.js') }}"></script>
    <script src="{{ url_for('static', filename='js/actions.js') }}"></script>
    <script src="{{ url_for('static', filename='js/highlight.pack.js') }}"></script>

    <!-- script for this page -->


  </body>
</html>

