				{% set counter = 0 -%}
					{"items":[
					{% for name in kb_name -%}
					    {"title":"{{name|safe}}",
					    {"description":"{{content|safe}}",
					{% set counter = counter + 1 %}
					]}
         			{% endfor %}
