<!-- 
    Security Knowledge Framework is an expert system application 
    that uses OWASP Application Security Verification Standard, code examples,
    helps developers in pre-development and post-development.  
    Copyright (C) 2015  Glenn ten Cate, Riccardo ten Cate

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
-->
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Security Knowledge Framework</title>

    <!-- Bootstrap core CSS -->
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/bootstrap.css') }}">
    <link rel="stylesheet" href="{{ url_for('static', filename='font-awesome/css/font-awesome.css') }}">
    <!-- Custom static for this template -->
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/style.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/style-responsive.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/table-responsive.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/monokai_sublime.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='js/animsition/animsition.min.css') }}">
    <script src="{{ url_for('static', filename='js/jquery.min.js') }}"></script>
    <script src="{{ url_for('static', filename='js/ajax.js') }}"></script>
	<script src="https://ajax.googleapis.com/ajax/libs/jquery/2.1.4/jquery.min.js"></script>
    <!-- HTML5 shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!--[if lt IE 9]>
      <script src="{{ url_for('static', filename='js/html5shiv.js') }}"></script>
      <script src="{{ url_for('static', filename='js/respond.min.js') }}"></script>

    <![endif]-->
  </head>
  <body onload="hljs.initHighlighting();">
  <section id="container" class="animsition">
      <!-- **********************************************************************************************************************************************************
      TOP BAR CONTENT & NOTIFICATIONS
      *********************************************************************************************************************************************************** -->
      <!--header start-->
      <header class="header black-bg">
            <!--logo start-->
            <a href="/dashboard" class="logo"><img class="img" width="35" height="35" src="/static/img/logos/logo.svg" alt="Logo" /> Security Knowledge Framework </a>
            <!--logo end-->
            <div class="top-menu">
            	<ul class="nav pull-right top-menu">
                    <li><a class="logout" href="/logout"><i class="fa fa-power-off"></i> Logout</a></li>
            	</ul>
            </div>
            <div style='margin-top:14px; margin-right:55px;' class="btn-group pull-right theme-container animated tada">
                <button class="btn btn-default dropdown-toggle" data-toggle="dropdown">
                    <i class="fa fa-code"></i><span class="hidden-sm hidden-xs"> Code Language </span>
                    <span class="caret"></span>
                </button>
                <ul class="dropdown-menu" id="themes">
                    <li><a href="/code/php">PHP</a></li>
                   <li><a href="/code/asp">C# .NET</a></li>
                  <li><a href="javascript:;">JAVA <span class="label">Coming Soon</span></a></li>
                </ul>
            </div>
        </header>
      <!--header end--> 

  
      <!-- **********************************************************************************************************************************************************
      MAIN SIDEBAR MENU
      *********************************************************************************************************************************************************** -->
      <!--sidebar start-->
      <aside>
          <div id="sidebar"  class="nav-collapse ">
              <!-- sidebar menu start-->
              <ul class="sidebar-menu" id="nav-accordion">
                  {% if "edit" in session['permissions'] -%}
                  <li class="mt sub-menu">
					<a class="page01" href="javascript:;">
						<i class="fa fa-file-code-o"></i>
						<span>Projects</span>
					</a>
					<ul class="sub">
						{% if "edit" in session['permissions'] -%} <li><a class="page02" href="/project-new">New Project</a></li>{% endif -%}
						{% if "read" in session['permissions'] -%}<li><a class="page03" href="/project-list">List Projects</a></li>{% endif -%}
						{% if "read" in session['permissions'] -%}<li><a class="page03a" href="/project-shared">Shared Projects</a></li>{% endif -%}
					</ul>
                  </li>
                  {% endif -%}
                  {% if "manage" in session['permissions'] -%}
                  <li class="sub-menu">
                      <a class="users" href="javascript:;" >
                          <i class="fa fa-user"></i>
                          <span>Users</span>
                      </a>
                      <ul class="sub">
                          <li><a class="userAdd" href="/users-new">Add users</a></li>
                          <li><a class="userManage" href="/users-manage">Manage users</a></li>
                      </ul>
                  </li>
                  {% endif -%}
                  {% if "edit" in session['permissions'] -%}
                  <li class="sub-menu">
                      <a class="pageA" href="javascript:;" >
                          <i class="fa fa-users"></i>
                          <span>User groups</span>
                      </a>
                      <ul class="sub">
                          <li><a class="pageB" href="/group-new">Add groups</a></li>
                          <li><a class="pageC" href="/group-users">Add users to group</a></li>
                          <li><a class="pageD" href="/group-manage">Manage groups</a></li>
                      </ul>
                  </li>
                  {% endif -%}
                  <li class="sub-menu">
                      <a class="page04" href="javascript:;" >
                          <i class="fa fa-bar-chart-o"></i>
                          <span>Results</span>
                      </a>
                      <ul class="sub">
                          <li><a class="page05" href="/results-checklists">Checklists</a></li>
                          <li><a class="page06" href="/results-functions">Functions</a></li>
                      </ul>
                  </li>
                  <li class="">
                      <a class="page07" href="/knowledge-base">
                          <i class="fa fa-book"></i>
                          <span>Knowledge Base</span>
                      </a>
                  </li>
                  <li class="">
                      <a class="page08" href="/code-examples">
                          <i class="fa fa-code"></i>
                          <span>Code examples</span>
                      </a>
                  </li>         
              </ul>
			  
			  <div class="copy">
					<img width="40" height="40" src="/static/img/logos/owasp-icon-grey.svg"> Supported by <a href="https://www.owasp.org/index.php?title=OWASP_Security_Knowledge_Framework">OWASP</a>
			  </div>
			  
              <!-- sidebar menu end-->
          </div>
      </aside>
      <!--sidebar end-->
 
