/* WIZARD GENERAL */
.wizard {
	display:none;	
}

.wizard-dialog {}
.wizard-content {}

.wizard-body {
	padding: 0;
	margin: 0;
}
	        
/* WIZARD HEADER */
.wizard-header {
	padding: 9px 15px;
	border-bottom: 0;
}

.wizard-header h3 {
	margin: 0;
	line-height: 35px;
	display: inline;
	font-family: 'Helvetica Neue', Helvetica, Arial, sans-serif;
	font-family: inherit;
	font-weight: bold;
	text-rendering: optimizelegibility;
	color: rgb(51, 51, 51);
}

.wizard-subtitle {
	font-weight:bold;
	color:#AFAFAF;
	padding-left:20px;
}


/* WIZARD NAVIGATION */
.wizard-steps {
	width: 28%;
	background-color: #f5f5f5;
	border-bottom-left-radius: 6px;
	position: relative;
	margin-right: 15px;
}

.wizard-nav-container {
	padding-bottom: 30px;
}

.wizard-nav-list {
	margin-bottom: 0;
}

.wizard-nav-link .glyphicon-chevron-right {
	float:right;
	margin-top:12px;
	margin-right:-6px;
	opacity:.25;
}

li.wizard-nav-item.active .glyphicon-chevron-right {
	opacity:1;
}

li.wizard-nav-item {
	line-height:40px;
}

.wizard-nav-list > li > a {
	background-color:#f5f5f5;
	padding:3px 15px 3px 20px;
	cursor:default;
	color:#B4B4B4;
}

.wizard-nav-list > li > a:hover {
	background-color: transparent;
}

.wizard-nav-list > li.already-visited > a.wizard-nav-link {
	color:#08C;
	cursor:pointer;
}

.wizard-nav-list > li.active > a.wizard-nav-link {
	color:white;
}

.wizard-nav-item .already-visited .active {
	background-color:#08C;
}

.wizard-nav-list li.active > a {
	background-color:#08C;
}


/* WIZARD CONTENT */
.wizard-body form {
	padding: 0;
	margin: 0;
}

/* WIZARD PROGRESS BAR */
.wizard-progress-container {
	margin-top: 20px;
	padding: 15px;
	width: 80%;
	position: absolute;
	bottom: 0;
}

.wizard-card-container {
	margin-left: 28%;
}

/* WIZARD CARDS */
.wizard-error,
.wizard-failure,
.wizard-success,
.wizard-loading,
.wizard-card {
	border-top: 1px solid #EEE;
	display:none;
	padding:35px;
	padding-top:20px;
	overflow-y:auto;
	
	/*
	position:relative;
	height:300px;
	margin-right: 5px;
	*/
}

.wizard-card-overlay {
	overflow-y: initial;
}

.wizard-card > h3 {
	margin-top:0;
	margin-bottom:20px;
	font-size:21px;
	line-height:40px;
	font-weight:normal;
}

/* WIZARD FOOTER */
.wizard-footer {
	padding:0;
}

.wizard-buttons-container {
	padding:20px;
}

.wizard-cancel {
	margin-left: 12px;
}

/* Inner Card */
.wizard-input-section {
	margin-bottom:20px;
}

.wizard-dialog .popover.error-popover {
	background-color:#F2DEDE;
	color:#B94A48;
	border-color:#953B39;
}

.wizard-dialog .popover.error-popover .arrow::after {
	border-right-color:#F2DEDE;
}

.wizard-dialog .popover.error-popover .popover-title {
	display:none;
}

.wizard-dialog .popover.error-popover .arrow {
	border-right-color:#953B39;
}
