<!-- 
    Security Knowledge Framework is an expert system application 
    that uses OWASP Application Security Verification Standard, code examples,
    helps developers in pre-development and post-development.  
    Copyright (C) 2015  Glenn ten Cate, Riccardo ten Cate

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
-->

{% include 'header.html' %}

<!-- **********************************************************************************************************************************************************
      MAIN CONTENT
      *********************************************************************************************************************************************************** -->
      <!--main content start-->
	  <script>
			  $(function(){
			$("#dropdown").change( function(e) {
				this.form.submit();
			});
		});
	  </script>
	  
      <section id="main-content" class="page03 project-list">

          <section class="intro">
			<div class="inner">
			
				<div class="text">
				
				<h1>All projects</h1>
				<p>View and add processing functions and checklists by clicking on a project name.</p>
				
				</div>
				
			</div>
		  </section>		  
		  
		  <section class="wrapper">
		  {% if not entries -%}
		  <h1>No projects available yet!</h1>
		  {% endif -%}

                  <div class="row mt">
                      <div class="col-lg-12">
                        <div class="content-panel">
                        
                        {% if entries -%}
                         <table class="table table-striped table-advance table-hover">
                              <thead>
                              <tr>
                                  <th><i class="fa fa-bullhorn"></i> Project Name</th>
                                  <th class="hidden-phone"><i class="fa fa-question-circle"></i> Description</th>
                                  <th><i class="fa fa-bookmark"></i> Project version</th>
                                  <th><i class="fa fa-clock-o"></i> Date/Time</th>
                                  
                                  {% if "delete" in session['permissions'] -%} 
                                  <th><i class="fa fa-times"></i> Delete</th>
                                  {% endif -%}
                                  
                                  <th><i class="fa fa-users"></i>Assign Group</th>
                                  <th><i class="fa fa-long-arrow-down"></i>Current</th>
                                  <th></th>
                              </tr>
                              </thead>
                              <tbody>
                              {% endif -%}

                                        {% set counter = 0 -%}
                                        {% for entry in entries -%}
                  <div id="projectRow{{entry.projectID|safe}}">
                              <tr>
                                  <td><a href="/project-options/{{entry.projectID|safe}}">{{entry.projectName|safe}}</a></td>
                                  <td style='max-width:250px;' class="hidden-phone">{{entry.projectDesc|safe}}</td>
                                  <td>{{entry.projectVersion|safe}}</td>
                                  <td><span class="label label-info label-mini">{{entry.timestamp|safe}}</span></td>
                                  <td>  <!-- Button trigger modal -->
                                  
                                  {% if "delete" in session['permissions'] -%} 
                                  <button class="btn btn-danger btn-xs" data-toggle="modal" data-target="#myModal{{entry.projectId|safe}}">
                                  <i class="fa fa-times "></i>                 
                                  </button></td>
                                  <td>
                                  {% endif -%}
									
									  <form method="post" action="assign-group" id="assignGroup">
										  <select onchange="this.form.submit();" id="dropdown{{counter}}" name="groupID" >
										  <option selected="selected">Assign group</option>
									  	 {% for group in groups -%}
									  	  <option value="{{group.groupID}}">{{group.groupName}}</option>
									  	  {% endfor %}
									  	  </select>
									  	  <input type="hidden" value="{{csrf_token|safe}}" name="csrf_token"/>
									  	  <input type="hidden" name="projectID" value="{{entry.projectID|safe}}"/>
									  </form>
									  </td>
                                  	<td style='max-width:250px;' class="hidden-phone">{{entry.groupName|safe}}
                       
                                  <!-- Modal -->
                                  <div class="modal fade" id="myModal{{entry.projectId|safe}}" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">
                                  <div class="modal-dialog">
                                  <div class="modal-content">
                                  <div class="modal-header">
                                  <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                                  <h4 class="modal-title" id="myModalLabel">Warning</h4>
                                  </div>
                                  <div   class="modal-body">
                                  <table id='checklist' style="width:525px">
                                 
                        <p>When you press the "Remove project" button, This project will be deleted<br/>
                        Are you sure you want to continue.
                        </p>


                                  </table>
                                  </div>
                                  <div class="modal-footer">
                                  <form method="POST" action="/project-del">
                                  <input type="hidden" value="{{entry.projectID|safe}}" name="projectID"/>
                                  <input type="hidden" value="{{csrf_token|safe}}" name="csrf_token"/>
                                  <button type="button" class="btn btn-default" data-dismiss="modal">Close</button>
                                  <input type="submit" value="Remove Project" id="" class="btn btn-danger"/>
                                  </form>
                                  </div>
                                  </div>
                                    </div>
                                  </div>                     
                                    </div>
                    </div>
                          </div>               </td>
                                  <td>

                                  </td>
                              </tr>   
                                        {% set counter = counter + 1 %}
                                        {% endfor %}
                             
                    
                              </tbody>
                          </table>
                      </div>
   
               </div><!-- /col-lg-4 -->           
              </div><!-- /row -->
        </section><!--/wrapper -->
      </section><!-- /MAIN CONTENT -->
       
{% include 'footer.html' %} 