<!-- 
    Security Knowledge Framework is an expert system application 
    that uses OWASP Application Security Verification Standard, code examples,
    helps developers in pre-development and post-development.  
    Copyright (C) 2015  Glenn ten Cate, Riccardo ten Cate

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
-->

{% include 'header.html' %}
      
 
<!-- **********************************************************************************************************************************************************
      MAIN CONTENT
      *********************************************************************************************************************************************************** -->
      <!--main content start-->
      <section id="main-content" class="dashboard">
          <section class="intro">
			<div class="inner">
			
				<div class="text">
				
				<h1>Security knowledge framework</h1>
				<p>In order to provide you with accurate data about your application the framework needs to know what processing functions are included in your application. Create a new project to get started if you haven't done so already.</p>
				
				</div>
				
				{% if version_check == False -%}

				<div class="data-panel">
					<ul>
						<li>
							<span class="name">SKF Version:</span> 
							<span class="version">{{version|safe}}</span>
							<span class="update">
								<a href="https://github.com/blabla1337/skf-flask">Update available</a>
							</span>
						</li>
					</ul>
				</div>
				
				{% endif %}

			</div>
		  </section>
		  <section class="wrapper">

		  		<div class="row mt">
			  		<div class="col-lg-12">
						<div class="content-panel selection four">
							<div class="row">
								<ul>
									<li>
										<a href="/project-new">
											<span class="icon"><i class="fa fa-file-code-o fa-4x"></i></span>
											<span class="name">Start new project</span>
										</a>
									</li>
									<li>
										<a href="/project-list">
											<span class="icon"><i class="fa fa-file-text-o fa-4x"></i></span>
											<span class="name">Edit existing project</span>
										</a>
									</li>
									<li>
										<a href="/knowledge-base">
											<span class="icon"><i class="fa fa-book fa-4x"></i></span>
											<span class="name">Security knowledge base</span>
										</a>
									</li>
									<li>
										<a href="/code-examples">
											<span class="icon"><i class="fa fa-code fa-4x"></i></span>
											<span class="name">Code examples</span>
										</a>
									</li>
								</ul>
							</div>
						</div>
					</div>
               </div>			

		</section><!--/wrapper -->
      </section><!-- /MAIN CONTENT -->
      <!--main content end-->
{% include 'footer.html' %}

