<!-- 
    Security Knowledge Framework is an expert system application 
    that uses OWASP Application Security Verification Standard, code examples,
    helps developers in pre-development and post-development.  
    Copyright (C) 2015  Glenn ten Cate, Riccardo ten Cate

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
-->

{% include 'header.html' %}

<!-- **********************************************************************************************************************************************************
      MAIN CONTENT
      *********************************************************************************************************************************************************** -->
      <!--main content start-->

      <section id="main-content">

		<section class="intro">
			<div class="inner">

				<div class="text">

					<h1>Search: <span class="term">Keyword</span></h1>

				</div>

			</div>
		</section>		  
	  
        <section class="wrapper">
          	
			<div class="search">
				<form  method="post" action="/code-search">
					<input type="search" name="search" placeholder="Search vulnerability"/>
					<button type="submit"><i class="fa fa-search"></i></button>
				</form>
			</div>	
			
		       <div class="row mt">
            <div class="col-lg-12">
                    <div class="panel-group" id="accordion">
            {% set counter = 0 -%}
            {% for entry in content %}
						  <div class="panel panel-default">
						    <div class="panel-heading" style='background-color:white;'>
						      <h4 class="panel-title">
						        <a data-toggle="collapse" data-parent="#accordion" href="#collapse{{counter|safe}}">
						    {{ kb_name[counter] }} 
						        </a>
						      </h4>
						    </div>
						    <div id="collapse{{counter|safe}}" class="panel-collapse collapse">
						      <div class="panel-body" style='background-color:#f5f5f5;'>
							{{ entry }}	
						      </div>
						    </div>
						  </div>
          {% set counter = counter + 1 %}	
          {% endfor %}  
          </div>
        </div><!-- /col-lg-4 -->
        {% if not content %}
          <div class="col-lg-12">
       		   <h2>Sorry we did not find anything</h2>
			   <a class="back" href="/code-examples">Back to code examples</a>
      	  </div>
        {% endif %}
		  	</div><!-- /row -->
		</section><!--/wrapper -->
      </section><!-- /MAIN CONTENT -->
         
{% include 'footer.html' %}

