<!-- 
    Security Knowledge Framework is an expert system application 
    that uses OWASP Application Security Verification Standard, code examples,
    helps developers in pre-development and post-development.  
    Copyright (C) 2015  Glenn ten Cate, Riccardo ten Cate

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
-->
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Security Knowledge Framework: Login</title>

    <!-- Bootstrap core CSS -->
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/bootstrap.css') }}">
    <link rel="stylesheet" href="{{ url_for('static', filename='font-awesome/css/font-awesome.css') }}">
    <!-- Custom static for this template -->
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/style.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/style-responsive.css') }}">
    <link rel="stylesheet" type="text/css" href="{{ url_for('static', filename='css/table-responsive.css') }}">
    <script src="{{ url_for('static', filename='js/jquery.min.js') }}"></script>

    <!-- HTML5 shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!--[if lt IE 9]>
      <script src="{{ url_for('static', filename='js/html5shiv.js') }}"></script>
      <script src="{{ url_for('static', filename='js/respond.min.js') }}"></script>

    <![endif]-->
  </head>


  <body id="login">

      <!-- **********************************************************************************************************************************************************
      MAIN CONTENT
      *********************************************************************************************************************************************************** -->
	
	<!-- UNLOCK -->
	
	  	<div class="container">
	  	
	  			<div class="col-wrapper">
	  				<div class="lock-screen">
	  									
				          <div class="login-wrapper"> 
				        
							<div class="logo"><img src="static/img/logos/logo.svg" width="60" height="60" /></div>
						
							<div class="modal-dialog">
				                  <div class="modal-content">
				                      <div class="modal-header">
				                          <h4 class="modal-title">Security Knowledge Framework</h4>
				                      </div>
				                      <div class="modal-body">
				                      <h1>warning</h1>
										<p> Your account has been blocked due to the suspicion of hacking<br/>
										This message can also occur whenever your account has not been properly activated yet<br/>
										Contact your administrator to unlock your account
										</p>
										
				                      </div>
				                  </div>
				              </div>
							  
							  <div class="copy">
									<img src="static/img/logos/owasp-icon-grey.svg" width="40" height="40" /> Supported by <a href="https://www.owasp.org/index.php?title=OWASP_Security_Knowledge_Framework">OWASP</a>
							  </div>
							  
				          </div>
				          <!-- modal -->
		  				
		  				
	  				</div><!--/lock-screen -->
	  			</div><!-- /col-lg-4 -->
	  	
	  	</div><!-- /container -->
  <!-- js placed at the end of the document so the pages load faster -->
    <script src="{{ url_for('static', filename='js/bootstrap.min.js') }}"></script>

  </body>
</html>
